diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/__init__.py b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/__init__.py
index 14b9f9d15..65ece09c6 100644
--- a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/__init__.py
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/__init__.py
@@ -982,6 +982,8 @@ class FunctionView(PGChildNodeView, DataTypeReader, SchemaDiffObjectCompare):
 
         resp_data['func_args_without'] = ', '.join(args_without_name)
 
+        self.reformat_prosrc_code(resp_data)
+
         if self.node_type == 'procedure':
             object_type = 'procedure'
             if 'provolatile' in resp_data:
@@ -1265,6 +1267,8 @@ class FunctionView(PGChildNodeView, DataTypeReader, SchemaDiffObjectCompare):
                     for v in data['variables']['added']:
                         data['merged_variables'].append(v)
 
+            self.reformat_prosrc_code(data)
+
             SQL = render_template(
                 "/".join([self.sql_template_path, 'update.sql']),
                 data=data, o_data=old_data
@@ -1309,6 +1313,9 @@ class FunctionView(PGChildNodeView, DataTypeReader, SchemaDiffObjectCompare):
             data['func_args'] = args.strip(' ')
 
             data['func_args_without'] = ', '.join(args_without_name)
+
+            self.reformat_prosrc_code(data)
+
             # Create mode
             SQL = render_template("/".join([self.sql_template_path,
                                             'create.sql']),
@@ -1653,6 +1660,27 @@ class FunctionView(PGChildNodeView, DataTypeReader, SchemaDiffObjectCompare):
                                json_resp=False)
         return sql
 
+    def reformat_prosrc_code(self, data):
+
+        if 'prosrc' in data and data['prosrc'] is not None:
+
+            is_prc_version_lesser_than_11 = \
+                self.node_type == 'procedure' and\
+                self.manager.sversion <= 110000
+
+            data['prosrc'] = re.sub(r"^\s+", '',
+                                    re.sub(r"\s+$", '',
+                                           data['prosrc']))
+
+            if not is_prc_version_lesser_than_11:
+                if data['prosrc'].startswith('\n') is False:
+                    data['prosrc'] = ''.join(
+                        ('\n', data['prosrc']))
+
+                if data['prosrc'].endswith('\n') is False:
+                    data['prosrc'] = ''.join(
+                        (data['prosrc'], '\n'))
+
     @check_precondition
     def fetch_objects_to_compare(self, sid, did, scid, oid=None):
         """
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/pg/11_plus/alter_proc_comment.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/pg/11_plus/alter_proc_comment.sql
index a347843fd..86eae9aca 100644
--- a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/pg/11_plus/alter_proc_comment.sql
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/pg/11_plus/alter_proc_comment.sql
@@ -5,9 +5,11 @@
 CREATE OR REPLACE PROCEDURE public."Proc1_$%{}[]()&*^!@""'`\/#"(
 	i1 integer)
 LANGUAGE 'plpgsql'
-AS $BODY$begin
+AS $BODY$
+begin
 select 1;
-end;$BODY$;
+end;
+$BODY$;
 
 COMMENT ON PROCEDURE public."Proc1_$%{}[]()&*^!@""'`\/#"(integer)
     IS 'some comment';
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/pg/11_plus/alter_proc_param.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/pg/11_plus/alter_proc_param.sql
index 02f43ce2e..4a8b0b176 100644
--- a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/pg/11_plus/alter_proc_param.sql
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/pg/11_plus/alter_proc_param.sql
@@ -6,9 +6,11 @@ CREATE OR REPLACE PROCEDURE public."Proc1_$%{}[]()&*^!@""'`\/#"(
 	i1 integer)
 LANGUAGE 'plpgsql'
     SET application_name='pgadmin'
-AS $BODY$begin
+AS $BODY$
+begin
 select 1;
-end;$BODY$;
+end;
+$BODY$;
 
 COMMENT ON PROCEDURE public."Proc1_$%{}[]()&*^!@""'`\/#"(integer)
     IS 'some comment';
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/pg/11_plus/alter_ptrig_comment.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/pg/11_plus/alter_ptrig_comment.sql
index 9dd7e3e03..5f2e770c6 100644
--- a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/pg/11_plus/alter_ptrig_comment.sql
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/pg/11_plus/alter_ptrig_comment.sql
@@ -7,9 +7,11 @@ CREATE FUNCTION public."Trig1_$%{}[]()&*^!@""'`\/#"()
     LANGUAGE 'plpgsql'
     COST 100
     VOLATILE NOT LEAKPROOF
-AS $BODY$begin
+AS $BODY$
+begin
 select 1;
-end;$BODY$;
+end;
+$BODY$;
 
 ALTER FUNCTION public."Trig1_$%{}[]()&*^!@""'`\/#"()
     OWNER TO postgres;
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/pg/11_plus/alter_ptrig_set_1.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/pg/11_plus/alter_ptrig_set_1.sql
index 17b9502dd..bf4885285 100644
--- a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/pg/11_plus/alter_ptrig_set_1.sql
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/pg/11_plus/alter_ptrig_set_1.sql
@@ -7,9 +7,11 @@ CREATE FUNCTION public."Trig1_$%{}[]()&*^!@""'`\/#"()
     LANGUAGE 'plpgsql'
     COST 100
     STABLE LEAKPROOF STRICT SECURITY DEFINER
-AS $BODY$begin
+AS $BODY$
+begin
 select 1;
-end;$BODY$;
+end;
+$BODY$;
 
 ALTER FUNCTION public."Trig1_$%{}[]()&*^!@""'`\/#"()
     OWNER TO postgres;
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/pg/11_plus/alter_ptrig_set_2.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/pg/11_plus/alter_ptrig_set_2.sql
index d388f9479..c14baa20a 100644
--- a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/pg/11_plus/alter_ptrig_set_2.sql
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/pg/11_plus/alter_ptrig_set_2.sql
@@ -9,9 +9,11 @@ CREATE FUNCTION public."Trig1_$%{}[]()&*^!@""'`\/#"()
     IMMUTABLE LEAKPROOF STRICT SECURITY DEFINER
     SET application_name='appname'
     SET search_path=public, pg_temp
-AS $BODY$begin
+AS $BODY$
+begin
 select 1;
-end;$BODY$;
+end;
+$BODY$;
 
 ALTER FUNCTION public."Trig1_$%{}[]()&*^!@""'`\/#"()
     OWNER TO postgres;
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/pg/11_plus/alter_ptrig_set_3.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/pg/11_plus/alter_ptrig_set_3.sql
index c3ae2b164..7caebc3b7 100644
--- a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/pg/11_plus/alter_ptrig_set_3.sql
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/pg/11_plus/alter_ptrig_set_3.sql
@@ -10,9 +10,11 @@ CREATE FUNCTION public."Trig1_$%{}[]()&*^!@""'`\/#"()
     SET application_name='appname2'
     SET search_path=public, pg_catalog
     SET array_nulls='true'
-AS $BODY$begin
+AS $BODY$
+begin
 select 1;
-end;$BODY$;
+end;
+$BODY$;
 
 ALTER FUNCTION public."Trig1_$%{}[]()&*^!@""'`\/#"()
     OWNER TO postgres;
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/pg/11_plus/create_event_trigger_full.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/pg/11_plus/create_event_trigger_full.sql
index 020e6126f..1bdbb6e01 100644
--- a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/pg/11_plus/create_event_trigger_full.sql
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/pg/11_plus/create_event_trigger_full.sql
@@ -9,9 +9,11 @@ CREATE FUNCTION public."Trig1_$%{}[]()&*^!@""'`\/#"()
     VOLATILE LEAKPROOF STRICT SECURITY DEFINER WINDOW
     ROWS 4321
     SET application_name='appname'
-AS $BODY$begin
+AS $BODY$
+begin
 select 1;
-end;$BODY$;
+end;
+$BODY$;
 
 ALTER FUNCTION public."Trig1_$%{}[]()&*^!@""'`\/#"()
     OWNER TO postgres;
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/pg/11_plus/create_plain_trigger.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/pg/11_plus/create_plain_trigger.sql
index 3758fe14e..191e59c8e 100644
--- a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/pg/11_plus/create_plain_trigger.sql
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/pg/11_plus/create_plain_trigger.sql
@@ -7,9 +7,11 @@ CREATE FUNCTION public."Trig1_$%{}[]()&*^!@""'`\/#"()
     LANGUAGE 'plpgsql'
     COST 100
     VOLATILE NOT LEAKPROOF
-AS $BODY$begin
+AS $BODY$
+begin
 select 1;
-end;$BODY$;
+end;
+$BODY$;
 
 ALTER FUNCTION public."Trig1_$%{}[]()&*^!@""'`\/#"()
     OWNER TO postgres;
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/pg/11_plus/create_plain_trigger_full.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/pg/11_plus/create_plain_trigger_full.sql
index eaa6d3bdc..3a51119ea 100644
--- a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/pg/11_plus/create_plain_trigger_full.sql
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/pg/11_plus/create_plain_trigger_full.sql
@@ -10,9 +10,11 @@ CREATE FUNCTION public."Trig1_$%{}[]()&*^!@""'`\/#"()
     ROWS 4321
     SET application_name='appname'
     SET search_path=public, pg_temp
-AS $BODY$begin
+AS $BODY$
+begin
 select 1;
-end;$BODY$;
+end;
+$BODY$;
 
 ALTER FUNCTION public."Trig1_$%{}[]()&*^!@""'`\/#"()
     OWNER TO postgres;
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/pg/11_plus/create_procedure.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/pg/11_plus/create_procedure.sql
index 8683b794d..c6b648237 100644
--- a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/pg/11_plus/create_procedure.sql
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/pg/11_plus/create_procedure.sql
@@ -5,6 +5,8 @@
 CREATE OR REPLACE PROCEDURE public."Proc1_$%{}[]()&*^!@""'`\/#"(
 	i1 integer)
 LANGUAGE 'plpgsql'
-AS $BODY$begin
+AS $BODY$
+begin
 select 1;
-end;$BODY$;
+end;
+$BODY$;
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/pg/default/alter_ptrig_comment.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/pg/default/alter_ptrig_comment.sql
index 9dd7e3e03..5f2e770c6 100644
--- a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/pg/default/alter_ptrig_comment.sql
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/pg/default/alter_ptrig_comment.sql
@@ -7,9 +7,11 @@ CREATE FUNCTION public."Trig1_$%{}[]()&*^!@""'`\/#"()
     LANGUAGE 'plpgsql'
     COST 100
     VOLATILE NOT LEAKPROOF
-AS $BODY$begin
+AS $BODY$
+begin
 select 1;
-end;$BODY$;
+end;
+$BODY$;
 
 ALTER FUNCTION public."Trig1_$%{}[]()&*^!@""'`\/#"()
     OWNER TO postgres;
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/pg/default/alter_ptrig_set_1.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/pg/default/alter_ptrig_set_1.sql
index 17b9502dd..bf4885285 100644
--- a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/pg/default/alter_ptrig_set_1.sql
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/pg/default/alter_ptrig_set_1.sql
@@ -7,9 +7,11 @@ CREATE FUNCTION public."Trig1_$%{}[]()&*^!@""'`\/#"()
     LANGUAGE 'plpgsql'
     COST 100
     STABLE LEAKPROOF STRICT SECURITY DEFINER
-AS $BODY$begin
+AS $BODY$
+begin
 select 1;
-end;$BODY$;
+end;
+$BODY$;
 
 ALTER FUNCTION public."Trig1_$%{}[]()&*^!@""'`\/#"()
     OWNER TO postgres;
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/pg/default/alter_ptrig_set_2.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/pg/default/alter_ptrig_set_2.sql
index d388f9479..c14baa20a 100644
--- a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/pg/default/alter_ptrig_set_2.sql
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/pg/default/alter_ptrig_set_2.sql
@@ -9,9 +9,11 @@ CREATE FUNCTION public."Trig1_$%{}[]()&*^!@""'`\/#"()
     IMMUTABLE LEAKPROOF STRICT SECURITY DEFINER
     SET application_name='appname'
     SET search_path=public, pg_temp
-AS $BODY$begin
+AS $BODY$
+begin
 select 1;
-end;$BODY$;
+end;
+$BODY$;
 
 ALTER FUNCTION public."Trig1_$%{}[]()&*^!@""'`\/#"()
     OWNER TO postgres;
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/pg/default/alter_ptrig_set_3.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/pg/default/alter_ptrig_set_3.sql
index c3ae2b164..7caebc3b7 100644
--- a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/pg/default/alter_ptrig_set_3.sql
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/pg/default/alter_ptrig_set_3.sql
@@ -10,9 +10,11 @@ CREATE FUNCTION public."Trig1_$%{}[]()&*^!@""'`\/#"()
     SET application_name='appname2'
     SET search_path=public, pg_catalog
     SET array_nulls='true'
-AS $BODY$begin
+AS $BODY$
+begin
 select 1;
-end;$BODY$;
+end;
+$BODY$;
 
 ALTER FUNCTION public."Trig1_$%{}[]()&*^!@""'`\/#"()
     OWNER TO postgres;
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/pg/default/create_event_trigger_full.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/pg/default/create_event_trigger_full.sql
index 020e6126f..1bdbb6e01 100644
--- a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/pg/default/create_event_trigger_full.sql
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/pg/default/create_event_trigger_full.sql
@@ -9,9 +9,11 @@ CREATE FUNCTION public."Trig1_$%{}[]()&*^!@""'`\/#"()
     VOLATILE LEAKPROOF STRICT SECURITY DEFINER WINDOW
     ROWS 4321
     SET application_name='appname'
-AS $BODY$begin
+AS $BODY$
+begin
 select 1;
-end;$BODY$;
+end;
+$BODY$;
 
 ALTER FUNCTION public."Trig1_$%{}[]()&*^!@""'`\/#"()
     OWNER TO postgres;
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/pg/default/create_plain_trigger.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/pg/default/create_plain_trigger.sql
index 3758fe14e..191e59c8e 100644
--- a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/pg/default/create_plain_trigger.sql
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/pg/default/create_plain_trigger.sql
@@ -7,9 +7,11 @@ CREATE FUNCTION public."Trig1_$%{}[]()&*^!@""'`\/#"()
     LANGUAGE 'plpgsql'
     COST 100
     VOLATILE NOT LEAKPROOF
-AS $BODY$begin
+AS $BODY$
+begin
 select 1;
-end;$BODY$;
+end;
+$BODY$;
 
 ALTER FUNCTION public."Trig1_$%{}[]()&*^!@""'`\/#"()
     OWNER TO postgres;
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/pg/default/create_plain_trigger_full.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/pg/default/create_plain_trigger_full.sql
index eaa6d3bdc..3a51119ea 100644
--- a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/pg/default/create_plain_trigger_full.sql
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/pg/default/create_plain_trigger_full.sql
@@ -10,9 +10,11 @@ CREATE FUNCTION public."Trig1_$%{}[]()&*^!@""'`\/#"()
     ROWS 4321
     SET application_name='appname'
     SET search_path=public, pg_temp
-AS $BODY$begin
+AS $BODY$
+begin
 select 1;
-end;$BODY$;
+end;
+$BODY$;
 
 ALTER FUNCTION public."Trig1_$%{}[]()&*^!@""'`\/#"()
     OWNER TO postgres;
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/11_plus/alter_proc_comment.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/11_plus/alter_proc_comment.sql
index a347843fd..86eae9aca 100644
--- a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/11_plus/alter_proc_comment.sql
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/11_plus/alter_proc_comment.sql
@@ -5,9 +5,11 @@
 CREATE OR REPLACE PROCEDURE public."Proc1_$%{}[]()&*^!@""'`\/#"(
 	i1 integer)
 LANGUAGE 'plpgsql'
-AS $BODY$begin
+AS $BODY$
+begin
 select 1;
-end;$BODY$;
+end;
+$BODY$;
 
 COMMENT ON PROCEDURE public."Proc1_$%{}[]()&*^!@""'`\/#"(integer)
     IS 'some comment';
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/11_plus/alter_proc_param.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/11_plus/alter_proc_param.sql
index 02f43ce2e..4a8b0b176 100644
--- a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/11_plus/alter_proc_param.sql
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/11_plus/alter_proc_param.sql
@@ -6,9 +6,11 @@ CREATE OR REPLACE PROCEDURE public."Proc1_$%{}[]()&*^!@""'`\/#"(
 	i1 integer)
 LANGUAGE 'plpgsql'
     SET application_name='pgadmin'
-AS $BODY$begin
+AS $BODY$
+begin
 select 1;
-end;$BODY$;
+end;
+$BODY$;
 
 COMMENT ON PROCEDURE public."Proc1_$%{}[]()&*^!@""'`\/#"(integer)
     IS 'some comment';
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/11_plus/alter_ptrig_comment.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/11_plus/alter_ptrig_comment.sql
index 3e29facee..477d57210 100644
--- a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/11_plus/alter_ptrig_comment.sql
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/11_plus/alter_ptrig_comment.sql
@@ -7,9 +7,11 @@ CREATE FUNCTION public."Trig1_$%{}[]()&*^!@""'`\/#"()
     LANGUAGE 'plpgsql'
     COST 100
     VOLATILE NOT LEAKPROOF
-AS $BODY$begin
+AS $BODY$
+begin
 select 1;
-end;$BODY$;
+end;
+$BODY$;
 
 ALTER FUNCTION public."Trig1_$%{}[]()&*^!@""'`\/#"()
     OWNER TO enterprisedb;
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/11_plus/alter_ptrig_set_1.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/11_plus/alter_ptrig_set_1.sql
index 5c72bfff5..91f3b188b 100644
--- a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/11_plus/alter_ptrig_set_1.sql
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/11_plus/alter_ptrig_set_1.sql
@@ -7,9 +7,11 @@ CREATE FUNCTION public."Trig1_$%{}[]()&*^!@""'`\/#"()
     LANGUAGE 'plpgsql'
     COST 100
     STABLE LEAKPROOF STRICT SECURITY DEFINER
-AS $BODY$begin
+AS $BODY$
+begin
 select 1;
-end;$BODY$;
+end;
+$BODY$;
 
 ALTER FUNCTION public."Trig1_$%{}[]()&*^!@""'`\/#"()
     OWNER TO enterprisedb;
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/11_plus/alter_ptrig_set_2.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/11_plus/alter_ptrig_set_2.sql
index 95a902c60..7c7b337d3 100644
--- a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/11_plus/alter_ptrig_set_2.sql
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/11_plus/alter_ptrig_set_2.sql
@@ -9,9 +9,11 @@ CREATE FUNCTION public."Trig1_$%{}[]()&*^!@""'`\/#"()
     IMMUTABLE LEAKPROOF STRICT SECURITY DEFINER
     SET application_name='appname'
     SET search_path=public, pg_temp
-AS $BODY$begin
+AS $BODY$
+begin
 select 1;
-end;$BODY$;
+end;
+$BODY$;
 
 ALTER FUNCTION public."Trig1_$%{}[]()&*^!@""'`\/#"()
     OWNER TO enterprisedb;
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/11_plus/alter_ptrig_set_3.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/11_plus/alter_ptrig_set_3.sql
index cfbcac9ef..f5de4196a 100644
--- a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/11_plus/alter_ptrig_set_3.sql
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/11_plus/alter_ptrig_set_3.sql
@@ -10,9 +10,11 @@ CREATE FUNCTION public."Trig1_$%{}[]()&*^!@""'`\/#"()
     SET application_name='appname2'
     SET search_path=public, pg_catalog
     SET array_nulls='true'
-AS $BODY$begin
+AS $BODY$
+begin
 select 1;
-end;$BODY$;
+end;
+$BODY$;
 
 ALTER FUNCTION public."Trig1_$%{}[]()&*^!@""'`\/#"()
     OWNER TO enterprisedb;
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/11_plus/create_event_trigger_full.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/11_plus/create_event_trigger_full.sql
index 86a8a3437..2f37a0c89 100644
--- a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/11_plus/create_event_trigger_full.sql
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/11_plus/create_event_trigger_full.sql
@@ -9,9 +9,11 @@ CREATE FUNCTION public."Trig1_$%{}[]()&*^!@""'`\/#"()
     VOLATILE LEAKPROOF STRICT SECURITY DEFINER WINDOW
     ROWS 4321
     SET application_name='appname'
-AS $BODY$begin
+AS $BODY$
+begin
 select 1;
-end;$BODY$;
+end;
+$BODY$;
 
 ALTER FUNCTION public."Trig1_$%{}[]()&*^!@""'`\/#"()
     OWNER TO enterprisedb;
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/11_plus/create_plain_trigger.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/11_plus/create_plain_trigger.sql
index 8ba939ec8..99e66f526 100644
--- a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/11_plus/create_plain_trigger.sql
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/11_plus/create_plain_trigger.sql
@@ -7,9 +7,11 @@ CREATE FUNCTION public."Trig1_$%{}[]()&*^!@""'`\/#"()
     LANGUAGE 'plpgsql'
     COST 100
     VOLATILE NOT LEAKPROOF
-AS $BODY$begin
+AS $BODY$
+begin
 select 1;
-end;$BODY$;
+end;
+$BODY$;
 
 ALTER FUNCTION public."Trig1_$%{}[]()&*^!@""'`\/#"()
     OWNER TO enterprisedb;
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/11_plus/create_plain_trigger_full.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/11_plus/create_plain_trigger_full.sql
index 211236227..8ba2ad109 100644
--- a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/11_plus/create_plain_trigger_full.sql
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/11_plus/create_plain_trigger_full.sql
@@ -10,9 +10,11 @@ CREATE FUNCTION public."Trig1_$%{}[]()&*^!@""'`\/#"()
     ROWS 4321
     SET application_name='appname'
     SET search_path=public, pg_temp
-AS $BODY$begin
+AS $BODY$
+begin
 select 1;
-end;$BODY$;
+end;
+$BODY$;
 
 ALTER FUNCTION public."Trig1_$%{}[]()&*^!@""'`\/#"()
     OWNER TO enterprisedb;
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/11_plus/create_procedure.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/11_plus/create_procedure.sql
index 8683b794d..c6b648237 100644
--- a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/11_plus/create_procedure.sql
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/11_plus/create_procedure.sql
@@ -5,6 +5,8 @@
 CREATE OR REPLACE PROCEDURE public."Proc1_$%{}[]()&*^!@""'`\/#"(
 	i1 integer)
 LANGUAGE 'plpgsql'
-AS $BODY$begin
+AS $BODY$
+begin
 select 1;
-end;$BODY$;
+end;
+$BODY$;
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/9.6_plus/alter_proc_comment.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/9.6_plus/alter_proc_comment.sql
index 1f27c5719..754559bd2 100644
--- a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/9.6_plus/alter_proc_comment.sql
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/9.6_plus/alter_proc_comment.sql
@@ -6,7 +6,7 @@ CREATE OR REPLACE PROCEDURE public."Proc1_$%{}[]()&*^!@""'`\/#"(
 	i1 integer)
     VOLATILE SECURITY DEFINER
     COST 100
-AS  begin
+AS begin
 select 1;
 end;
 
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/9.6_plus/alter_proc_opt.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/9.6_plus/alter_proc_opt.sql
index 4ea874ae9..fd1073634 100644
--- a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/9.6_plus/alter_proc_opt.sql
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/9.6_plus/alter_proc_opt.sql
@@ -7,7 +7,7 @@ CREATE OR REPLACE PROCEDURE public."Proc1_$%{}[]()&*^!@""'`\/#"(
     STABLE SECURITY DEFINER PARALLEL RESTRICTED
     COST 120
     SET application_name='pgadmin'
-AS   begin
+AS begin
 select 1;
 end;
 
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/9.6_plus/alter_proc_opt_msql.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/9.6_plus/alter_proc_opt_msql.sql
index d4c87487b..fd1073634 100644
--- a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/9.6_plus/alter_proc_opt_msql.sql
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/9.6_plus/alter_proc_opt_msql.sql
@@ -7,7 +7,7 @@ CREATE OR REPLACE PROCEDURE public."Proc1_$%{}[]()&*^!@""'`\/#"(
     STABLE SECURITY DEFINER PARALLEL RESTRICTED
     COST 120
     SET application_name='pgadmin'
-AS  begin
+AS begin
 select 1;
 end;
 
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/9.6_plus/alter_proc_param.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/9.6_plus/alter_proc_param.sql
index fbe458bf2..6a6244b1b 100644
--- a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/9.6_plus/alter_proc_param.sql
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/9.6_plus/alter_proc_param.sql
@@ -7,7 +7,7 @@ CREATE OR REPLACE PROCEDURE public."Proc1_$%{}[]()&*^!@""'`\/#"(
     VOLATILE SECURITY DEFINER
     COST 100
     SET application_name='pgadmin'
-AS  begin
+AS begin
 select 1;
 end;
 
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/9.6_plus/alter_ptrig_comment.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/9.6_plus/alter_ptrig_comment.sql
index 3e29facee..477d57210 100644
--- a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/9.6_plus/alter_ptrig_comment.sql
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/9.6_plus/alter_ptrig_comment.sql
@@ -7,9 +7,11 @@ CREATE FUNCTION public."Trig1_$%{}[]()&*^!@""'`\/#"()
     LANGUAGE 'plpgsql'
     COST 100
     VOLATILE NOT LEAKPROOF
-AS $BODY$begin
+AS $BODY$
+begin
 select 1;
-end;$BODY$;
+end;
+$BODY$;
 
 ALTER FUNCTION public."Trig1_$%{}[]()&*^!@""'`\/#"()
     OWNER TO enterprisedb;
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/9.6_plus/alter_ptrig_set_1.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/9.6_plus/alter_ptrig_set_1.sql
index 5c72bfff5..91f3b188b 100644
--- a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/9.6_plus/alter_ptrig_set_1.sql
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/9.6_plus/alter_ptrig_set_1.sql
@@ -7,9 +7,11 @@ CREATE FUNCTION public."Trig1_$%{}[]()&*^!@""'`\/#"()
     LANGUAGE 'plpgsql'
     COST 100
     STABLE LEAKPROOF STRICT SECURITY DEFINER
-AS $BODY$begin
+AS $BODY$
+begin
 select 1;
-end;$BODY$;
+end;
+$BODY$;
 
 ALTER FUNCTION public."Trig1_$%{}[]()&*^!@""'`\/#"()
     OWNER TO enterprisedb;
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/9.6_plus/alter_ptrig_set_2.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/9.6_plus/alter_ptrig_set_2.sql
index 95a902c60..7c7b337d3 100644
--- a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/9.6_plus/alter_ptrig_set_2.sql
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/9.6_plus/alter_ptrig_set_2.sql
@@ -9,9 +9,11 @@ CREATE FUNCTION public."Trig1_$%{}[]()&*^!@""'`\/#"()
     IMMUTABLE LEAKPROOF STRICT SECURITY DEFINER
     SET application_name='appname'
     SET search_path=public, pg_temp
-AS $BODY$begin
+AS $BODY$
+begin
 select 1;
-end;$BODY$;
+end;
+$BODY$;
 
 ALTER FUNCTION public."Trig1_$%{}[]()&*^!@""'`\/#"()
     OWNER TO enterprisedb;
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/9.6_plus/alter_ptrig_set_3.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/9.6_plus/alter_ptrig_set_3.sql
index cfbcac9ef..f5de4196a 100644
--- a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/9.6_plus/alter_ptrig_set_3.sql
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/9.6_plus/alter_ptrig_set_3.sql
@@ -10,9 +10,11 @@ CREATE FUNCTION public."Trig1_$%{}[]()&*^!@""'`\/#"()
     SET application_name='appname2'
     SET search_path=public, pg_catalog
     SET array_nulls='true'
-AS $BODY$begin
+AS $BODY$
+begin
 select 1;
-end;$BODY$;
+end;
+$BODY$;
 
 ALTER FUNCTION public."Trig1_$%{}[]()&*^!@""'`\/#"()
     OWNER TO enterprisedb;
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/9.6_plus/create_event_trigger_full.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/9.6_plus/create_event_trigger_full.sql
index 86a8a3437..2f37a0c89 100644
--- a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/9.6_plus/create_event_trigger_full.sql
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/9.6_plus/create_event_trigger_full.sql
@@ -9,9 +9,11 @@ CREATE FUNCTION public."Trig1_$%{}[]()&*^!@""'`\/#"()
     VOLATILE LEAKPROOF STRICT SECURITY DEFINER WINDOW
     ROWS 4321
     SET application_name='appname'
-AS $BODY$begin
+AS $BODY$
+begin
 select 1;
-end;$BODY$;
+end;
+$BODY$;
 
 ALTER FUNCTION public."Trig1_$%{}[]()&*^!@""'`\/#"()
     OWNER TO enterprisedb;
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/9.6_plus/create_plain_trigger.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/9.6_plus/create_plain_trigger.sql
index 8ba939ec8..99e66f526 100644
--- a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/9.6_plus/create_plain_trigger.sql
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/9.6_plus/create_plain_trigger.sql
@@ -7,9 +7,11 @@ CREATE FUNCTION public."Trig1_$%{}[]()&*^!@""'`\/#"()
     LANGUAGE 'plpgsql'
     COST 100
     VOLATILE NOT LEAKPROOF
-AS $BODY$begin
+AS $BODY$
+begin
 select 1;
-end;$BODY$;
+end;
+$BODY$;
 
 ALTER FUNCTION public."Trig1_$%{}[]()&*^!@""'`\/#"()
     OWNER TO enterprisedb;
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/9.6_plus/create_plain_trigger_full.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/9.6_plus/create_plain_trigger_full.sql
index 211236227..8ba2ad109 100644
--- a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/9.6_plus/create_plain_trigger_full.sql
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/9.6_plus/create_plain_trigger_full.sql
@@ -10,9 +10,11 @@ CREATE FUNCTION public."Trig1_$%{}[]()&*^!@""'`\/#"()
     ROWS 4321
     SET application_name='appname'
     SET search_path=public, pg_temp
-AS $BODY$begin
+AS $BODY$
+begin
 select 1;
-end;$BODY$;
+end;
+$BODY$;
 
 ALTER FUNCTION public."Trig1_$%{}[]()&*^!@""'`\/#"()
     OWNER TO enterprisedb;
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/9.6_plus/create_procedure.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/9.6_plus/create_procedure.sql
index 325a80e8b..9c4e1fccb 100644
--- a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/9.6_plus/create_procedure.sql
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/9.6_plus/create_procedure.sql
@@ -6,6 +6,6 @@ CREATE OR REPLACE PROCEDURE public."Proc1_$%{}[]()&*^!@""'`\/#"(
 	i1 integer)
     VOLATILE SECURITY DEFINER
     COST 100
-AS  begin
+AS begin
 select 1;
 end;
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/default/alter_proc_comment.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/default/alter_proc_comment.sql
index 1f27c5719..754559bd2 100644
--- a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/default/alter_proc_comment.sql
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/default/alter_proc_comment.sql
@@ -6,7 +6,7 @@ CREATE OR REPLACE PROCEDURE public."Proc1_$%{}[]()&*^!@""'`\/#"(
 	i1 integer)
     VOLATILE SECURITY DEFINER
     COST 100
-AS  begin
+AS begin
 select 1;
 end;
 
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/default/alter_proc_opt.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/default/alter_proc_opt.sql
index 05f9d0354..147ebbe02 100644
--- a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/default/alter_proc_opt.sql
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/default/alter_proc_opt.sql
@@ -7,7 +7,7 @@ CREATE OR REPLACE PROCEDURE public."Proc1_$%{}[]()&*^!@""'`\/#"(
     STABLE SECURITY DEFINER
     COST 120
     SET application_name='pgadmin'
-AS   begin
+AS begin
 select 1;
 end;
 
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/default/alter_proc_opt_msql.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/default/alter_proc_opt_msql.sql
index 6b6ba43f5..147ebbe02 100644
--- a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/default/alter_proc_opt_msql.sql
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/default/alter_proc_opt_msql.sql
@@ -7,7 +7,7 @@ CREATE OR REPLACE PROCEDURE public."Proc1_$%{}[]()&*^!@""'`\/#"(
     STABLE SECURITY DEFINER
     COST 120
     SET application_name='pgadmin'
-AS  begin
+AS begin
 select 1;
 end;
 
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/default/alter_proc_param.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/default/alter_proc_param.sql
index fbe458bf2..6a6244b1b 100644
--- a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/default/alter_proc_param.sql
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/default/alter_proc_param.sql
@@ -7,7 +7,7 @@ CREATE OR REPLACE PROCEDURE public."Proc1_$%{}[]()&*^!@""'`\/#"(
     VOLATILE SECURITY DEFINER
     COST 100
     SET application_name='pgadmin'
-AS  begin
+AS begin
 select 1;
 end;
 
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/default/alter_ptrig_comment.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/default/alter_ptrig_comment.sql
index 3e29facee..477d57210 100644
--- a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/default/alter_ptrig_comment.sql
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/default/alter_ptrig_comment.sql
@@ -7,9 +7,11 @@ CREATE FUNCTION public."Trig1_$%{}[]()&*^!@""'`\/#"()
     LANGUAGE 'plpgsql'
     COST 100
     VOLATILE NOT LEAKPROOF
-AS $BODY$begin
+AS $BODY$
+begin
 select 1;
-end;$BODY$;
+end;
+$BODY$;
 
 ALTER FUNCTION public."Trig1_$%{}[]()&*^!@""'`\/#"()
     OWNER TO enterprisedb;
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/default/alter_ptrig_set_1.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/default/alter_ptrig_set_1.sql
index 5c72bfff5..91f3b188b 100644
--- a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/default/alter_ptrig_set_1.sql
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/default/alter_ptrig_set_1.sql
@@ -7,9 +7,11 @@ CREATE FUNCTION public."Trig1_$%{}[]()&*^!@""'`\/#"()
     LANGUAGE 'plpgsql'
     COST 100
     STABLE LEAKPROOF STRICT SECURITY DEFINER
-AS $BODY$begin
+AS $BODY$
+begin
 select 1;
-end;$BODY$;
+end;
+$BODY$;
 
 ALTER FUNCTION public."Trig1_$%{}[]()&*^!@""'`\/#"()
     OWNER TO enterprisedb;
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/default/alter_ptrig_set_2.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/default/alter_ptrig_set_2.sql
index 95a902c60..7c7b337d3 100644
--- a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/default/alter_ptrig_set_2.sql
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/default/alter_ptrig_set_2.sql
@@ -9,9 +9,11 @@ CREATE FUNCTION public."Trig1_$%{}[]()&*^!@""'`\/#"()
     IMMUTABLE LEAKPROOF STRICT SECURITY DEFINER
     SET application_name='appname'
     SET search_path=public, pg_temp
-AS $BODY$begin
+AS $BODY$
+begin
 select 1;
-end;$BODY$;
+end;
+$BODY$;
 
 ALTER FUNCTION public."Trig1_$%{}[]()&*^!@""'`\/#"()
     OWNER TO enterprisedb;
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/default/alter_ptrig_set_3.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/default/alter_ptrig_set_3.sql
index cfbcac9ef..f5de4196a 100644
--- a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/default/alter_ptrig_set_3.sql
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/default/alter_ptrig_set_3.sql
@@ -10,9 +10,11 @@ CREATE FUNCTION public."Trig1_$%{}[]()&*^!@""'`\/#"()
     SET application_name='appname2'
     SET search_path=public, pg_catalog
     SET array_nulls='true'
-AS $BODY$begin
+AS $BODY$
+begin
 select 1;
-end;$BODY$;
+end;
+$BODY$;
 
 ALTER FUNCTION public."Trig1_$%{}[]()&*^!@""'`\/#"()
     OWNER TO enterprisedb;
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/default/create_event_trigger_full.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/default/create_event_trigger_full.sql
index 86a8a3437..2f37a0c89 100644
--- a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/default/create_event_trigger_full.sql
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/default/create_event_trigger_full.sql
@@ -9,9 +9,11 @@ CREATE FUNCTION public."Trig1_$%{}[]()&*^!@""'`\/#"()
     VOLATILE LEAKPROOF STRICT SECURITY DEFINER WINDOW
     ROWS 4321
     SET application_name='appname'
-AS $BODY$begin
+AS $BODY$
+begin
 select 1;
-end;$BODY$;
+end;
+$BODY$;
 
 ALTER FUNCTION public."Trig1_$%{}[]()&*^!@""'`\/#"()
     OWNER TO enterprisedb;
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/default/create_plain_trigger.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/default/create_plain_trigger.sql
index 8ba939ec8..99e66f526 100644
--- a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/default/create_plain_trigger.sql
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/default/create_plain_trigger.sql
@@ -7,9 +7,11 @@ CREATE FUNCTION public."Trig1_$%{}[]()&*^!@""'`\/#"()
     LANGUAGE 'plpgsql'
     COST 100
     VOLATILE NOT LEAKPROOF
-AS $BODY$begin
+AS $BODY$
+begin
 select 1;
-end;$BODY$;
+end;
+$BODY$;
 
 ALTER FUNCTION public."Trig1_$%{}[]()&*^!@""'`\/#"()
     OWNER TO enterprisedb;
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/default/create_plain_trigger_full.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/default/create_plain_trigger_full.sql
index 211236227..8ba2ad109 100644
--- a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/default/create_plain_trigger_full.sql
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/default/create_plain_trigger_full.sql
@@ -10,9 +10,11 @@ CREATE FUNCTION public."Trig1_$%{}[]()&*^!@""'`\/#"()
     ROWS 4321
     SET application_name='appname'
     SET search_path=public, pg_temp
-AS $BODY$begin
+AS $BODY$
+begin
 select 1;
-end;$BODY$;
+end;
+$BODY$;
 
 ALTER FUNCTION public."Trig1_$%{}[]()&*^!@""'`\/#"()
     OWNER TO enterprisedb;
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/default/create_procedure.sql b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/default/create_procedure.sql
index 325a80e8b..9c4e1fccb 100644
--- a/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/default/create_procedure.sql
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/functions/tests/ppas/default/create_procedure.sql
@@ -6,6 +6,6 @@ CREATE OR REPLACE PROCEDURE public."Proc1_$%{}[]()&*^!@""'`\/#"(
 	i1 integer)
     VOLATILE SECURITY DEFINER
     COST 100
-AS  begin
+AS begin
 select 1;
 end;
